@@ -2,7 +2,7 @@ package PICA::Parser::Plain;
 use strict;
 use warnings;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use charnames qw(:full);
 use constant SUBFIELD_INDICATOR => '$';
@@ -38,9 +38,32 @@ sub next_record {
             croak 'ERROR: no valid PICA field structure';
         }
 
-        my @subfields = split /\$([^\$])/, $data;
+        # data is byte sequence, no character sequence!
+        my @subfields = split /\$(\$+|.)/, $data;
         shift @subfields;
-        push @subfields, '' if @subfields % 2;
+        push @subfields, '' if @subfields % 2; # last subfield without value
+
+        if ($data =~ /\$\$/) {
+            my @tokens = (shift @subfields, shift @subfields);
+            while (@subfields) {
+                my $code  = shift @subfields;
+                my $value = shift @subfields;
+                if  ($code =~ /^\$+$/) {
+                    my $length = length $code;
+                    $code =~ s/\$\$/\$/g;
+                    if ($length % 2) {
+                        $tokens[-1] .= "$code$value";
+                        next;
+                    } else {
+                        $tokens[-1] .= $code;
+                        $code = substr $value, 0, 1; 
+                        $value = substr $value, 1;
+                    }
+                }
+                push @tokens, $code, $value;
+            }
+            @subfields = @tokens;
+        }
 
         push @record, [ $tag, $occurence, @subfields ];
     }
